@@ -39,8 +39,6 @@ eventuallyPrev s = s || tmp
   where
     tmp = [ False ] ++ s || tmp
 
--- | Once @s2@ holds, in the following state (period), does @s1@ continuously hold?
-since ::  Stream Bool -> Stream Bool -> Stream Bool
-since s1 s2 = alwaysBeen ( tmp ==> s1 )
-    where
-      tmp = eventuallyPrev $ [ False ] ++ s2
+-- | Is there a time when @s2@ holds and after which @s1@ continuously holds?
+since :: Stream Bool -> Stream Bool -> Stream Bool
+since s1 s2 = eventuallyPrev (s2 ==> (alwaysBeen s1))
